/*
 * Copyright (C) 2012 Intel Corporation.
 *
 * Author: Krzesimir Nowak <krnowak@openismus.com>
 *
 * This file is part of Rygel.
 *
 * Rygel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * Rygel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

using GUPnP;

/**
 * Represents a playlist item.
 *
 * These objects correspond to DLNA's DIDL_S items.
 */
public class Rygel.PlaylistItem : MediaFileItem {
    public new const string UPNP_CLASS = "object.item.playlistItem";

    public PlaylistItem (string         id,
                         MediaContainer parent,
                         string         title,
                         string         upnp_class = PlaylistItem.UPNP_CLASS) {
        Object (id : id,
                parent : parent,
                title : title,
                upnp_class : upnp_class);
    }

    internal override DIDLLiteObject? serialize (Serializer serializer,
                                                 HTTPServer http_server)
                                                 throws Error {
        var didl_item = base.serialize (serializer, http_server);

        return didl_item;
    }

    internal override MediaResource get_primary_resource () {
        var res = base.get_primary_resource ();

        res.dlna_flags |= DLNAFlags.INTERACTIVE_TRANSFER_MODE;

        return res;
    }
}
